==> kile-trinity_3.5.13.2.orig.tar.xz: kile-trinity-3.5.13.2/src/kile/floatdialog.h <==
/***************************************************************************
    date                 : Jan 28 2005
    version              : 0.10
    copyright            : (C) 2005 by Holger Danielsson
    email                : holger.danielsson@t-online.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef FLOATDIALOG_H
#define FLOATDIALOG_H

#include "kilewizard.h"
#include <klineedit.h>

#include <tqlabel.h>
#include <tqcheckbox.h>
#include <tqradiobutton.h>

#include "kileinfo.h"

namespace KileDialog
{

class FloatEnvironmentDialog : public Wizard  
{
	Q_OBJECT
  TQ_OBJECT

public:
	FloatEnvironmentDialog(KConfig *config, KileInfo *ki, TQWidget *parent);
	~FloatEnvironmentDialog() {}
	
public slots:
	void slotOk();

private slots:
	void slotEnvironmentClicked();

private:
	KLineEdit *m_edLabel, *m_edCaption;
	TQRadioButton *m_rbFigure, *m_rbTable;
	TQCheckBox *m_cbHere,*m_cbTop,*m_cbBottom,*m_cbPage;
	TQCheckBox *m_cbCenter;
	
	TQString m_prefix;
	KileInfo *m_ki;
};

}

#endif

==> kile-trinity_14.1.0.orig.tar.xz: kile-trinity-14.1.0/src/kile/floatdialog.h <==
/***************************************************************************
    date                 : Jan 28 2005
    version              : 0.10
    copyright            : (C) 2005 by Holger Danielsson
    email                : holger.danielsson@t-online.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef FLOATDIALOG_H
#define FLOATDIALOG_H

#include "kilewizard.h"
#include <klineedit.h>

#include <tqlabel.h>
#include <tqcheckbox.h>
#include <tqradiobutton.h>

#include "kileinfo.h"

namespace KileDialog
{

class FloatEnvironmentDialog : public Wizard  
{
	Q_OBJECT
  

public:
	FloatEnvironmentDialog(TDEConfig *config, KileInfo *ki, TQWidget *parent);
	~FloatEnvironmentDialog() {}
	
public slots:
	void slotOk();

private slots:
	void slotEnvironmentClicked();

private:
	KLineEdit *m_edLabel, *m_edCaption;
	TQRadioButton *m_rbFigure, *m_rbTable;
	TQCheckBox *m_cbHere,*m_cbTop,*m_cbBottom,*m_cbPage;
	TQCheckBox *m_cbCenter;
	
	TQString m_prefix;
	KileInfo *m_ki;
};

}

#endif
